pub enum ControllerEvent {
StreamStart {
session_id: i64,
message_id: String,
model: String,
turn_id: Option<TurnId>,
},
TextChunk {
session_id: i64,
text: String,
turn_id: Option<TurnId>,
},
ToolUseStart {
session_id: i64,
tool_id: String,
tool_name: String,
turn_id: Option<TurnId>,
},
ToolUse {
session_id: i64,
tool: ToolUseInfo,
display_name: Option<String>,
display_title: Option<String>,
turn_id: Option<TurnId>,
},
Complete {
session_id: i64,
stop_reason: Option<String>,
turn_id: Option<TurnId>,
},
Error {
session_id: i64,
error: String,
turn_id: Option<TurnId>,
},
TokenUpdate {
session_id: i64,
input_tokens: i64,
output_tokens: i64,
context_limit: i32,
},
ToolResult {
session_id: i64,
tool_use_id: String,
tool_name: String,
display_name: Option<String>,
status: ToolResultStatus,
content: String,
error: Option<String>,
turn_id: Option<TurnId>,
},
CommandComplete {
session_id: i64,
command: ControlCmd,
success: bool,
message: Option<String>,
},
UserInteractionRequired {
session_id: i64,
tool_use_id: String,
request: AskUserQuestionsRequest,
turn_id: Option<TurnId>,
},
PermissionRequired {
session_id: i64,
tool_use_id: String,
request: PermissionRequest,
turn_id: Option<TurnId>,
},
BatchPermissionRequired {
session_id: i64,
batch: BatchPermissionRequest,
turn_id: Option<TurnId>,
},
}Expand description
Event emitted by the controller
Variants
StreamStart
Streaming has started
TextChunk
Text chunk from LLM response
ToolUseStart
Tool use block has started (streaming)
ToolUse
Tool use requested by LLM (complete)
Fields

tool: ToolUseInfoComplete
Response complete
Error
Error occurred
TokenUpdate
Token usage update
ToolResult
Individual tool execution result (for UI feedback during batch execution)
Fields

status: ToolResultStatusCommandComplete
Control command completed
UserInteractionRequired
Tool is blocked waiting for user interaction (questions)
PermissionRequired
Tool is blocked waiting for permission from user
BatchPermissionRequired
Multiple tools are blocked waiting for batch permission from user. This is used when parallel tools need permissions - presenting all requests together avoids deadlocks and allows the user to make informed decisions.