pub struct BashTool { /* private fields */ }Expand description
Tool that executes bash commands with permission checks.
Implementations
Sourceimpl BashTool
impl BashTool
Sourcepub fn new(permission_registry: Arc<PermissionRegistry>) -> BashTool
pub fn new(permission_registry: Arc<PermissionRegistry>) -> BashTool
Create a new BashTool with the given permission registry.
Arguments
permission_registry- The registry used to request and cache permissions.
Sourcepub fn with_working_dir(
permission_registry: Arc<PermissionRegistry>,
working_dir: PathBuf,
) -> BashTool
pub fn with_working_dir( permission_registry: Arc<PermissionRegistry>, working_dir: PathBuf, ) -> BashTool
Create a new BashTool with a default working directory.
Arguments
permission_registry- The registry used to request and cache permissions.working_dir- The default working directory for commands.
Sourcepub async fn cleanup_session(&self, session_id: i64)
pub async fn cleanup_session(&self, session_id: i64)
Cleans up session-specific state when a session is removed.
This removes the working directory state for the given session, preventing unbounded memory growth from abandoned sessions.