pub struct GrepTool { /* private fields */ }Expand description
Tool that searches file contents using ripgrep with permission checks.
Implementations
Sourceimpl GrepTool
impl GrepTool
Sourcepub fn new(permission_registry: Arc<PermissionRegistry>) -> Self
pub fn new(permission_registry: Arc<PermissionRegistry>) -> Self
Create a new GrepTool with the given permission registry.
Arguments
permission_registry- The registry used to request and cache permissions.
Sourcepub fn with_default_path(
permission_registry: Arc<PermissionRegistry>,
default_path: PathBuf,
) -> Self
pub fn with_default_path( permission_registry: Arc<PermissionRegistry>, default_path: PathBuf, ) -> Self
Create a new GrepTool with a default search path.
Arguments
permission_registry- The registry used to request and cache permissions.default_path- The default directory to search if no path is provided.