pub fn parse_skill_md(path: &Path) -> Result<SkillMetadata, SkillDiscoveryError>Expand description
Parse a SKILL.md file and extract the metadata from its YAML frontmatter.
The file must start with --- followed by YAML content and another ---.
pub fn parse_skill_md(path: &Path) -> Result<SkillMetadata, SkillDiscoveryError>Parse a SKILL.md file and extract the metadata from its YAML frontmatter.
The file must start with --- followed by YAML content and another ---.