pub fn default_commands() -> Vec<Box<dyn SlashCommand>>Expand description
Returns the standard set of commands most agents will want.
Includes: help, clear, compact, themes, sessions, status, version, new-session, and quit.
pub fn default_commands() -> Vec<Box<dyn SlashCommand>>Returns the standard set of commands most agents will want.
Includes: help, clear, compact, themes, sessions, status, version, new-session, and quit.