Module table

Module table 

Table rendering utilities. Table rendering utilities for TUI

Supports multiple rendering strategies via trait.

Structs

PulldownRenderer
Renders tables using pulldown-cmark parsing

Traits

TableRenderer
Trait for table rendering strategies

Functions

is_table_line
Check if a line could be part of a table (contains |)
is_table_separator
Check if a line is a table separator (|—|—|)
render_table
Render a table using PulldownRenderer