pub enum BatchPermissionOption {
GrantOnce,
GrantSession,
GrantAllSimilar,
Deny,
}Expand description
Options available for batch permission decisions
Variants
GrantOnce
Grant permission for these requests only (no persistent grant)
GrantSession
Grant permission for the remainder of the session (these specific resources)
GrantAllSimilar
Grant permission for ALL operations of this type for the session (only shown for homogeneous read/write batches)
Deny
Deny all permission requests
Implementations
Sourceimpl BatchPermissionOption
impl BatchPermissionOption
Sourcepub fn description(
&self,
count: usize,
batch_type: Option<PermissionLevel>,
) -> String
pub fn description( &self, count: usize, batch_type: Option<PermissionLevel>, ) -> String
Get the description for this option based on batch context
Sourcepub fn is_positive(&self) -> bool
pub fn is_positive(&self) -> bool
Returns true if this is a positive (grant) option