pub enum PermissionOption {
GrantOnce,
GrantSession,
GrantAllSession,
Deny,
}Expand description
Options available for the user to select
Variants
GrantOnce
Grant permission for this request only (no persistent grant)
GrantSession
Grant permission for the remainder of the session (this specific resource)
GrantAllSession
Grant permission for ALL operations of this type for the session
Deny
Deny the permission request
Implementations
Sourceimpl PermissionOption
impl PermissionOption
Sourcepub fn all() -> &'static [PermissionOption]
pub fn all() -> &'static [PermissionOption]
Get all options in display order
Sourcepub fn description(&self, request: &PermissionRequest) -> String
pub fn description(&self, request: &PermissionRequest) -> String
Get the description for this option based on request context
Sourcepub fn is_positive(&self) -> bool
pub fn is_positive(&self) -> bool
Returns true if this is a positive (grant) option
Sourcepub fn to_response(
&self,
request: &PermissionRequest,
) -> PermissionPanelResponse
pub fn to_response( &self, request: &PermissionRequest, ) -> PermissionPanelResponse
Convert to a response with optional grant based on the request