Crate agent_core

Crate agent_core 

agent-core — foundational types, config, session, auth, logging, protocol, memory, and pricing. Leaf crate: no in-repo upward deps.

Re-exports

pub use core::stream_types::AgentEvent;
pub use core::stream_types::LlmEvent;
pub use core::stream_types::SessionEvent;
pub use core::stream_types::StreamEvent;
pub use core::config;
pub use core::session;
pub use core::auth;
pub use core::logging;
pub use core::protocol;
pub use core::error;
pub use core::watcher_types;
pub use core::models;
pub use core::chain;
pub use error::Result;
pub use error::RuntimeError;

Modules

core
Core infrastructure — config, session, auth, logging, error types, protocol.
memory
Local-first memory store.
pricing
Centralised pricing logic for Anthropic models.

Functions

epoch_millis
Current time as Unix epoch milliseconds. Panics only if system clock is before 1970.
truncate_str
Truncate a string to at most max bytes at a valid UTF-8 boundary.