pub fn load_config<A>(agent_config: &A) -> LLMRegistrywhere
A: AgentConfig,Expand description
Load config for an agent using its AgentConfig trait implementation.
Tries to load from the config file first, then falls back to environment variables. Supports both absolute paths and paths relative to home directory.